Documentation
¶
Index ¶
- Constants
- Variables
- func ActionStar(ctx *context.Context)
- func ActionTransfer(ctx *context.Context)
- func ActionWatch(ctx *context.Context)
- func Activity(ctx *context.Context)
- func ActivityAuthors(ctx *context.Context)
- func AddColumnToProjectPost(ctx *context.Context)
- func AddDependency(ctx *context.Context)
- func AddTimeManually(c *context.Context)
- func BatchDeleteIssues(ctx *context.Context)
- func Branches(ctx *context.Context)
- func CancelAutoMergePullRequest(ctx *context.Context)
- func CancelStopwatch(c *context.Context)
- func ChangeCommentReaction(ctx *context.Context)
- func ChangeIssueReaction(ctx *context.Context)
- func ChangeMilestoneStatus(ctx *context.Context)
- func ChangeProjectStatus(ctx *context.Context)
- func CherryPick(ctx *context.Context)
- func CherryPickPost(ctx *context.Context)
- func CleanUpPullRequest(ctx *context.Context)
- func CodeFrequency(ctx *context.Context)
- func CodeFrequencyData(ctx *context.Context)
- func Commits(ctx *context.Context)
- func CompareAndPullRequestPost(ctx *context.Context)
- func CompareDiff(ctx *context.Context)
- func Contributors(ctx *context.Context)
- func ContributorsData(ctx *context.Context)
- func CorsHandler() func(next http.Handler) http.Handler
- func Create(ctx *context.Context)
- func CreateBranch(ctx *context.Context)
- func CreateCodeComment(ctx *context.Context)
- func CreatePost(ctx *context.Context)
- func DeleteAttachment(ctx *context.Context)
- func DeleteBranchPost(ctx *context.Context)
- func DeleteComment(ctx *context.Context)
- func DeleteFile(ctx *context.Context)
- func DeleteFilePost(ctx *context.Context)
- func DeleteIssue(ctx *context.Context)
- func DeleteLabel(ctx *context.Context)
- func DeleteMilestone(ctx *context.Context)
- func DeleteProject(ctx *context.Context)
- func DeleteProjectColumn(ctx *context.Context)
- func DeleteRelease(ctx *context.Context)
- func DeleteTag(ctx *context.Context)
- func DeleteTime(c *context.Context)
- func DeleteWikiPagePost(ctx *context.Context)
- func Diff(ctx *context.Context)
- func DiffPreviewPost(ctx *context.Context)
- func DismissReview(ctx *context.Context)
- func Download(ctx *context.Context)
- func DownloadByID(ctx *context.Context)
- func DownloadByIDOrLFS(ctx *context.Context)
- func DownloadCompareDiff(ctx *context.Context)
- func DownloadComparePatch(ctx *context.Context)
- func DownloadPullDiff(ctx *context.Context)
- func DownloadPullDiffOrPatch(ctx *context.Context, patch bool)
- func DownloadPullPatch(ctx *context.Context)
- func EditFile(ctx *context.Context)
- func EditFilePost(ctx *context.Context)
- func EditMilestone(ctx *context.Context)
- func EditMilestonePost(ctx *context.Context)
- func EditProjectColumn(ctx *context.Context)
- func EditProjectPost(ctx *context.Context)
- func EditRelease(ctx *context.Context)
- func EditReleasePost(ctx *context.Context)
- func EditWiki(ctx *context.Context)
- func EditWikiPost(ctx *context.Context)
- func ExcerptBlob(ctx *context.Context)
- func FileHistory(ctx *context.Context)
- func Fork(ctx *context.Context)
- func ForkPost(ctx *context.Context)
- func ForkRepoTo(ctx *context.Context, owner *user_model.User, ...) *repo_model.Repository
- func ForkToEdit(ctx *context.Context)
- func ForkToEditPost(ctx *context.Context)
- func Forks(ctx *context.Context)
- func GenerateReleaseNotes(ctx *context.Context)
- func GetActionIssue(ctx *context.Context) *issues_model.Issue
- func GetAttachment(ctx *context.Context)
- func GetBranchesList(ctx *context.Context)
- func GetCommentAttachments(ctx *context.Context)
- func GetContentHistoryDetail(ctx *context.Context)
- func GetContentHistoryList(ctx *context.Context)
- func GetContentHistoryOverview(ctx *context.Context)
- func GetDiffViewStyle(ctx *context.Context) string
- func GetIdxFile(ctx *context.Context)
- func GetInfoPacks(ctx *context.Context)
- func GetInfoRefs(ctx *context.Context)
- func GetIssueAttachments(ctx *context.Context)
- func GetIssueInfo(ctx *context.Context)
- func GetLooseObject(ctx *context.Context)
- func GetMentionsInRepo(ctx *context.Context)
- func GetMergedBaseCommitID(ctx *context.Context, issue *issues_model.Issue) string
- func GetPackFile(ctx *context.Context)
- func GetPullCommits(ctx *context.Context)
- func GetPullDiffStats(ctx *context.Context)
- func GetShowOutdatedComments(ctx *context.Context) bool
- func GetTagList(ctx *context.Context)
- func GetTextFile(p string) func(*context.Context)
- func GetWhitespaceBehavior(ctx *context.Context) string
- func Graph(ctx *context.Context)
- func HTTPGitEnabledHandler(ctx *context.Context)
- func HandleGitError(ctx *context.Context, msg string, err error)
- func Home(ctx *context.Context)
- func InitializeLabels(ctx *context.Context)
- func InitiateDownload(ctx *context.Context)
- func IssuePinMove(ctx *context.Context)
- func IssuePinOrUnpin(ctx *context.Context)
- func IssuePullPosters(ctx *context.Context)
- func IssueStartStopwatch(c *context.Context)
- func IssueStopStopwatch(c *context.Context)
- func IssueSuggestions(ctx *context.Context)
- func IssueUnpin(ctx *context.Context)
- func IssueWatch(ctx *context.Context)
- func Issues(ctx *context.Context)
- func Labels(ctx *context.Context)
- func LastCommit(ctx *context.Context)
- func LatestRelease(ctx *context.Context)
- func LoadBranchesAndTags(ctx *context.Context)
- func LockIssue(ctx *context.Context)
- func MergePullRequest(ctx *context.Context)
- func MergeUpstream(ctx *context.Context)
- func Migrate(ctx *context.Context)
- func MigrateCancelPost(ctx *context.Context)
- func MigratePost(ctx *context.Context)
- func MigrateRetryPost(ctx *context.Context)
- func MigrateStatus(ctx *context.Context)
- func MilestoneIssuesAndPulls(ctx *context.Context)
- func Milestones(ctx *context.Context)
- func MoveIssues(ctx *context.Context)
- func MustAllowPulls(ctx *context.Context)
- func MustAllowUserComment(ctx *context.Context)
- func MustBeAbleToUpload(ctx *context.Context)
- func MustBeEditable(ctx *context.Context)
- func MustBeNotEmpty(ctx *context.Context)
- func MustEnableIssues(ctx *context.Context)
- func MustEnableRepoProjects(ctx *context.Context)
- func MustEnableWiki(ctx *context.Context)
- func NewComment(ctx *context.Context)
- func NewDiffPatch(ctx *context.Context)
- func NewDiffPatchPost(ctx *context.Context)
- func NewIssue(ctx *context.Context)
- func NewIssueChooseTemplate(ctx *context.Context)
- func NewIssuePost(ctx *context.Context)
- func NewLabel(ctx *context.Context)
- func NewMilestone(ctx *context.Context)
- func NewMilestonePost(ctx *context.Context)
- func NewProjectPost(ctx *context.Context)
- func NewRelease(ctx *context.Context)
- func NewReleasePost(ctx *context.Context)
- func NewWiki(ctx *context.Context)
- func NewWikiPost(ctx *context.Context)
- func Packages(ctx *context.Context)
- func PrepareBranchList(ctx *context.Context)
- func Projects(ctx *context.Context)
- func PullsNewRedirect(ctx *context.Context)
- func RawCommitURL(owner, name string, commit *git.Commit) string
- func RawDiff(ctx *context.Context)
- func RecentCommits(ctx *context.Context)
- func RedirectDownload(ctx *context.Context)
- func RedirectRepoBlobToCommit(ctx *context.Context)
- func RedirectRepoTreeToSrc(ctx *context.Context)
- func RefBlame(ctx *context.Context)
- func RefCommits(ctx *context.Context)
- func Releases(ctx *context.Context)
- func ReleasesFeedAtom(ctx *context.Context)
- func ReleasesFeedRSS(ctx *context.Context)
- func RemoveDependency(ctx *context.Context)
- func RemoveUploadFileFromServer(ctx *context.Context)
- func RenderEditProject(ctx *context.Context)
- func RenderFile(ctx *context.Context)
- func RenderNewCodeCommentForm(ctx *context.Context)
- func RenderNewProject(ctx *context.Context)
- func RenderUserCards(ctx *context.Context, total int, ...)
- func RestoreBranchPost(ctx *context.Context)
- func RetrieveLabelsForList(ctx *context.Context)
- func Search(ctx *context.Context)
- func SearchCommits(ctx *context.Context)
- func SearchIssues(ctx *context.Context)
- func SearchRepo(ctx *context.Context)
- func SearchRepoIssuesJSON(ctx *context.Context)
- func ServeAttachment(ctx *context.Context, uuid string)
- func ServeBlobOrLFS(ctx *context.Context, blob *git.Blob, lastModified *time.Time) error
- func ServiceReceivePack(ctx *context.Context)
- func ServiceUploadArchive(ctx *context.Context)
- func ServiceUploadPack(ctx *context.Context)
- func SetAllowEdits(ctx *context.Context)
- func SetDefaultProjectColumn(ctx *context.Context)
- func SetDiffViewStyle(ctx *context.Context)
- func SetEditorconfigIfExists(ctx *context.Context)
- func SetShowOutdatedComments(ctx *context.Context)
- func SetWhitespaceBehavior(ctx *context.Context)
- func SingleDownload(ctx *context.Context)
- func SingleDownloadOrLFS(ctx *context.Context)
- func SingleRelease(ctx *context.Context)
- func SoftDeleteContentHistory(ctx *context.Context)
- func SourceCommitURL(owner, name string, commit *git.Commit) string
- func Stars(ctx *context.Context)
- func SubmitReview(ctx *context.Context)
- func TagsList(ctx *context.Context)
- func TagsListFeedAtom(ctx *context.Context)
- func TagsListFeedRSS(ctx *context.Context)
- func TopicsPost(ctx *context.Context)
- func TreeList(ctx *context.Context)
- func TreeViewNodes(ctx *context.Context)
- func UnlockIssue(ctx *context.Context)
- func UpdateCommentContent(ctx *context.Context)
- func UpdateIssueAssignee(ctx *context.Context)
- func UpdateIssueContent(ctx *context.Context)
- func UpdateIssueDeadline(ctx *context.Context)
- func UpdateIssueLabel(ctx *context.Context)
- func UpdateIssueMilestone(ctx *context.Context)
- func UpdateIssueProject(ctx *context.Context)
- func UpdateIssueProjectColumn(ctx *context.Context)
- func UpdateIssueRef(ctx *context.Context)
- func UpdateIssueStatus(ctx *context.Context)
- func UpdateIssueTimeEstimate(ctx *context.Context)
- func UpdateIssueTitle(ctx *context.Context)
- func UpdateLabel(ctx *context.Context)
- func UpdatePullRequest(ctx *context.Context)
- func UpdatePullRequestTarget(ctx *context.Context)
- func UpdatePullReviewRequest(ctx *context.Context)
- func UpdateResolveConversation(ctx *context.Context)
- func UpdateViewedFiles(ctx *context.Context)
- func UploadFile(ctx *context.Context)
- func UploadFilePost(ctx *context.Context)
- func UploadFileToServer(ctx *context.Context)
- func UploadIssueAttachment(ctx *context.Context)
- func UploadReleaseAttachment(ctx *context.Context)
- func ValidateRepoMetasForNewIssue(ctx *context.Context, form forms.CreateIssueForm, isPull bool) (ret struct{ ... })
- func ViewIssue(ctx *context.Context)
- func ViewProject(ctx *context.Context)
- func ViewPullCommits(ctx *context.Context)
- func ViewPullFilesForAllCommitsOfPr(ctx *context.Context)
- func ViewPullFilesForRange(ctx *context.Context)
- func ViewPullFilesForSingleCommit(ctx *context.Context)
- func ViewPullMergeBox(ctx *context.Context)
- func Watchers(ctx *context.Context)
- func WebGitOperationCommonData(ctx *context.Context)
- func WebGitOperationGetCommitChosenEmailIdentity(ctx *context.Context, email string) (_ *files_service.IdentityOptions, valid bool)
- func Wiki(ctx *context.Context)
- func WikiPages(ctx *context.Context)
- func WikiPost(ctx *context.Context)
- func WikiRaw(ctx *context.Context)
- func WikiRevision(ctx *context.Context)
- type CodeEditorConfig
- type IssuePageMetaData
- type PageMeta
- type RecentBranchesPromptDataStruct
- type ReleaseInfo
- type WebDiffFileItem
- type WebDiffFileTree
Constants ¶
const ( ServiceTypeUploadPack = "upload-pack" ServiceTypeReceivePack = "receive-pack" ServiceTypeUploadArchive = "upload-archive" )
Variables ¶
var IssueTemplateCandidates = []string{
"ISSUE_TEMPLATE.md",
"ISSUE_TEMPLATE.yaml",
"ISSUE_TEMPLATE.yml",
"issue_template.md",
"issue_template.yaml",
"issue_template.yml",
".hanzo/ISSUE_TEMPLATE.md",
".hanzo/ISSUE_TEMPLATE.yaml",
".hanzo/ISSUE_TEMPLATE.yml",
".hanzo/issue_template.md",
".hanzo/issue_template.yaml",
".hanzo/issue_template.yml",
".github/ISSUE_TEMPLATE.md",
".github/ISSUE_TEMPLATE.yaml",
".github/ISSUE_TEMPLATE.yml",
".github/issue_template.md",
".github/issue_template.yaml",
".github/issue_template.yml",
}
IssueTemplateCandidates issue templates
Functions ¶
func ActionStar ¶
func ActionTransfer ¶
func ActionWatch ¶
func ActivityAuthors ¶
ActivityAuthors renders JSON with top commit authors for given time period over all branches
func AddColumnToProjectPost ¶
AddColumnToProjectPost allows a new column to be added to a project.
func AddTimeManually ¶
AddTimeManually tracks time manually
func BatchDeleteIssues ¶
func CancelAutoMergePullRequest ¶
CancelAutoMergePullRequest cancels a scheduled pr
func CancelStopwatch ¶
CancelStopwatch cancel the stopwatch
func ChangeCommentReaction ¶
ChangeCommentReaction create a reaction for comment
func ChangeIssueReaction ¶
ChangeIssueReaction create a reaction for issue
func ChangeMilestoneStatus ¶
ChangeMilestoneStatus response for change a milestone's status
func ChangeProjectStatus ¶
ChangeProjectStatus updates the status of a project between "open" and "close"
func CherryPick ¶
func CherryPickPost ¶
func CleanUpPullRequest ¶
CleanUpPullRequest responses for delete merged branch when PR has been merged Used by "DeleteBranchLink" for "delete branch" button
func CodeFrequency ¶
CodeFrequency renders the page to show repository code frequency
func CodeFrequencyData ¶
CodeFrequencyData returns JSON of code frequency data
func CompareAndPullRequestPost ¶
CompareAndPullRequestPost response for creating pull request
func CompareDiff ¶
CompareDiff show different from one commit to another commit
func Contributors ¶
Contributors render the page to show repository contributors graph
func ContributorsData ¶
ContributorsData renders JSON of contributors along with their weekly commit statistics
func CreateBranch ¶
CreateBranch creates new branch in repository
func CreateCodeComment ¶
CreateCodeComment will create a code comment including an pending review if required
func DeleteAttachment ¶
DeleteAttachment response for deleting issue's attachment
func DeleteBranchPost ¶
DeleteBranchPost responses for delete merged branch
func DeleteFilePost ¶
DeleteFilePost response for deleting file or directory
func DeleteMilestone ¶
DeleteMilestone delete a milestone
func DeleteProjectColumn ¶
DeleteProjectColumn allows for the deletion of a project column
func DeleteWikiPagePost ¶
DeleteWikiPagePost delete wiki page
func DiffPreviewPost ¶
func DismissReview ¶
DismissReview dismissing stale review by repo admin
func DownloadByIDOrLFS ¶
DownloadByIDOrLFS download a file by sha1 ID taking account of LFS
func DownloadCompareDiff ¶
DownloadCompareDiff render a comparison's raw unified diff
func DownloadComparePatch ¶
DownloadComparePatch render a comparison as a git format-patch
func DownloadPullDiff ¶
DownloadPullDiff render a pull's raw diff
func DownloadPullDiffOrPatch ¶
DownloadPullDiffOrPatch render a pull's raw diff or patch
func DownloadPullPatch ¶
DownloadPullPatch render a pull's raw patch
func EditFilePost ¶
func EditMilestone ¶
EditMilestone render edting milestone page
func EditMilestonePost ¶
EditMilestonePost response for edting milestone
func EditProjectColumn ¶
EditProjectColumn allows a project column's to be updated
func EditProjectPost ¶
EditProjectPost response for editing a project
func EditReleasePost ¶
EditReleasePost response for edit release
func EditWikiPost ¶
EditWikiPost response for wiki modify request
func ForkRepoTo ¶
func ForkRepoTo(ctx *context.Context, owner *user_model.User, forkOpts repo_service.ForkRepoOptions) *repo_model.Repository
func ForkToEdit ¶
func ForkToEditPost ¶
func GenerateReleaseNotes ¶
GenerateReleaseNotes builds release notes content for the given tag and base.
func GetActionIssue ¶
func GetActionIssue(ctx *context.Context) *issues_model.Issue
GetActionIssue will return the issue which is used in the context.
func GetBranchesList ¶
GetBranchesList get branches for current repo'
func GetCommentAttachments ¶
GetCommentAttachments returns attachments for the comment
func GetContentHistoryDetail ¶
GetContentHistoryDetail get detail
func GetContentHistoryList ¶
GetContentHistoryList get list
func GetContentHistoryOverview ¶
GetContentHistoryOverview get overview
func GetDiffViewStyle ¶
func GetIssueAttachments ¶
GetIssueAttachments returns attachments for the issue
func GetIssueInfo ¶
GetIssueInfo get an issue of a repository
func GetLooseObject ¶
GetLooseObject implements Git dumb HTTP
func GetMentionsInRepo ¶
GetMentionsInRepo returns JSON data for mention autocomplete (assignees, participants, mentionable teams).
func GetMergedBaseCommitID ¶
func GetMergedBaseCommitID(ctx *context.Context, issue *issues_model.Issue) string
func GetPullCommits ¶
GetPullCommits get all commits for given pull request
func GetPullDiffStats ¶
GetPullDiffStats get Pull Requests diff stats
func GetShowOutdatedComments ¶
func GetTextFile ¶
GetTextFile implements Git dumb HTTP
func GetWhitespaceBehavior ¶
func HTTPGitEnabledHandler ¶
func InitializeLabels ¶
InitializeLabels init labels for a repository
func InitiateDownload ¶
InitiateDownload will enqueue an archival request, as needed. It may submit a request that's already in-progress, but the archiver service will just kind of drop it on the floor if this is the case.
func IssuePinOrUnpin ¶
IssuePinOrUnpin pin or unpin a Issue
func IssuePullPosters ¶
func IssueStartStopwatch ¶
IssueStartStopwatch creates a stopwatch for the given issue.
func IssueStopStopwatch ¶
IssueStopStopwatch stops a stopwatch for the given issue.
func IssueSuggestions ¶
IssueSuggestions returns a list of issue suggestions
func LastCommit ¶
LastCommit returns lastCommit data for the provided branch/tag/commit and directory (in url) and filenames in body
func LatestRelease ¶
LatestRelease redirects to the latest release
func LoadBranchesAndTags ¶
func LockIssue ¶
LockIssue locks an issue. This would limit commenting abilities to users with write access to the repo.
func MergePullRequest ¶
MergePullRequest response for merging pull request
func MergeUpstream ¶
func MigrateCancelPost ¶
func MigratePost ¶
MigratePost response for migrating from external git repository
func MigrateRetryPost ¶
func MigrateStatus ¶
MigrateStatus returns migrate task's status
func MilestoneIssuesAndPulls ¶
MilestoneIssuesAndPulls lists all the issues and pull requests of the milestone
func MoveIssues ¶
MoveIssues moves or keeps issues in a column and sorts them inside that column
func MustAllowPulls ¶
MustAllowPulls check if repository enable pull requests and user have right to do that
func MustAllowUserComment ¶
MustAllowUserComment checks to make sure if an issue is locked. If locked and user has permissions to write to the repository, then the comment is allowed, else it is blocked
func MustBeAbleToUpload ¶
MustBeAbleToUpload check that repo can be uploaded to
func MustBeEditable ¶
MustBeEditable check that repo can be edited
func MustBeNotEmpty ¶
MustBeNotEmpty render when a repo is a empty git dir
func MustEnableIssues ¶
MustEnableIssues check if repository enable internal issues
func MustEnableRepoProjects ¶
MustEnableRepoProjects check if repo projects are enabled in settings
func MustEnableWiki ¶
MustEnableWiki check if wiki is enabled, if external then redirect
func NewDiffPatch ¶
func NewDiffPatchPost ¶
NewDiffPatchPost response for sending patch page
func NewIssueChooseTemplate ¶
NewIssueChooseTemplate render creating issue from template page
func NewIssuePost ¶
NewIssuePost response for creating new issue
func NewMilestone ¶
NewMilestone render creating milestone page
func NewMilestonePost ¶
NewMilestonePost response for creating milestone
func NewProjectPost ¶
NewProjectPost creates a new project
func NewRelease ¶
NewRelease render creating or edit release page
func NewReleasePost ¶
NewReleasePost response for creating a release
func NewWikiPost ¶
NewWikiPost response for wiki create request
func PrepareBranchList ¶
func PullsNewRedirect ¶
func RawCommitURL ¶
RawCommitURL creates a relative URL for the raw commit in the given repository
func RecentCommits ¶
RecentCommits renders the page to show recent commit frequency on repository
func RedirectDownload ¶
RedirectDownload return a file based on the following infos:
func RedirectRepoTreeToSrc ¶
func ReleasesFeedAtom ¶
ReleasesFeedAtom get feeds for releases in Atom format
func ReleasesFeedRSS ¶
ReleasesFeedRSS get feeds for releases in RSS format
func RemoveDependency ¶
RemoveDependency removes the dependency
func RemoveUploadFileFromServer ¶
RemoveUploadFileFromServer remove file from server file dir
func RenderEditProject ¶
RenderEditProject allows a project to be edited
func RenderNewCodeCommentForm ¶
RenderNewCodeCommentForm will render the form for creating a new review comment
func RenderNewProject ¶
RenderNewProject render creating a project page
func RenderUserCards ¶
func RenderUserCards(ctx *context.Context, total int, getter func(opts db.ListOptions) ([]*user_model.User, error), tpl templates.TplName)
RenderUserCards render a page show users according the input template
func RestoreBranchPost ¶
RestoreBranchPost responses for delete merged branch
func RetrieveLabelsForList ¶
RetrieveLabelsForList find all the labels of a repository and organization, it is only used by "/labels" page to list all labels
func SearchCommits ¶
SearchCommits render commits filtered by keyword
func SearchIssues ¶
SearchIssues searches for issues across the repositories that the user has access to
func SearchRepoIssuesJSON ¶
SearchRepoIssuesJSON lists the issues of a repository This function was copied from API (decouple the web and API routes), it is only used by frontend to search some dependency or related issues
func ServeAttachment ¶
ServeAttachment serve attachments with the given UUID
func ServeBlobOrLFS ¶
ServeBlobOrLFS download a git.Blob redirecting to LFS if necessary
func ServiceReceivePack ¶
ServiceReceivePack implements Git Smart HTTP protocol
func ServiceUploadArchive ¶
func ServiceUploadPack ¶
ServiceUploadPack implements Git Smart HTTP protocol
func SetAllowEdits ¶
SetAllowEdits allow edits from maintainers to PRs
func SetDefaultProjectColumn ¶
SetDefaultProjectColumn set default column for uncategorized issues/pulls
func SetDiffViewStyle ¶
SetDiffViewStyle set diff style as render variable
func SetEditorconfigIfExists ¶
SetEditorconfigIfExists set editor config as render variable
func SetShowOutdatedComments ¶
SetShowOutdatedComments set the show outdated comments option as context variable
func SetWhitespaceBehavior ¶
SetWhitespaceBehavior set whitespace behavior as render variable
func SingleDownload ¶
SingleDownload download a file by repos path
func SingleDownloadOrLFS ¶
SingleDownloadOrLFS download a file by repos path redirecting to LFS if necessary
func SingleRelease ¶
SingleRelease renders a single release's page
func SoftDeleteContentHistory ¶
SoftDeleteContentHistory soft delete
func SourceCommitURL ¶
SourceCommitURL creates a relative URL for a commit in the given repository
func SubmitReview ¶
SubmitReview creates a review out of the existing pending review or creates a new one if no pending review exist
func TagsListFeedAtom ¶
TagsListFeedAtom get feeds for tags in RSS format
func TagsListFeedRSS ¶
TagsListFeedRSS get feeds for tags in RSS format
func TreeViewNodes ¶
func UnlockIssue ¶
UnlockIssue unlocks a previously locked issue.
func UpdateCommentContent ¶
UpdateCommentContent change comment of issue's content
func UpdateIssueAssignee ¶
UpdateIssueAssignee change issue's or pull's assignee
func UpdateIssueContent ¶
UpdateIssueContent change issue's content
func UpdateIssueDeadline ¶
UpdateIssueDeadline updates an issue deadline
func UpdateIssueLabel ¶
UpdateIssueLabel change issue's labels
func UpdateIssueMilestone ¶
UpdateIssueMilestone change issue's milestone
func UpdateIssueProject ¶
UpdateIssueProject change an issue's project
func UpdateIssueProjectColumn ¶
UpdateIssueProjectColumn moves an issue to a different column within its project
func UpdateIssueRef ¶
UpdateIssueRef change issue's ref (branch)
func UpdateIssueStatus ¶
UpdateIssueStatus change issue's status
func UpdateIssueTimeEstimate ¶
func UpdateIssueTitle ¶
UpdateIssueTitle change issue's title
func UpdateLabel ¶
UpdateLabel update a label's name and color
func UpdatePullRequest ¶
UpdatePullRequest merge PR's baseBranch into headBranch
func UpdatePullRequestTarget ¶
UpdatePullRequestTarget change pull request's target branch
func UpdatePullReviewRequest ¶
UpdatePullReviewRequest add or remove review request
func UpdateResolveConversation ¶
UpdateResolveConversation add or remove an Conversation resolved mark
func UpdateViewedFiles ¶
func UploadFile ¶
func UploadFilePost ¶
func UploadFileToServer ¶
UploadFileToServer upload file to server file dir not git
func UploadIssueAttachment ¶
UploadIssueAttachment response for Issue/PR attachments
func UploadReleaseAttachment ¶
UploadReleaseAttachment response for uploading release attachments
func ValidateRepoMetasForNewIssue ¶
func ValidateRepoMetasForNewIssue(ctx *context.Context, form forms.CreateIssueForm, isPull bool) (ret struct { LabelIDs, AssigneeIDs []int64 MilestoneID int64 ProjectIDs []int64 Reviewers []*user_model.User TeamReviewers []*organization.Team }, )
ValidateRepoMetasForNewIssue check and returns repository's meta information
func ViewProject ¶
ViewProject renders the project with board view
func ViewPullCommits ¶
ViewPullCommits show commits for a pull request
func ViewPullFilesForRange ¶
func ViewPullMergeBox ¶
func WebGitOperationGetCommitChosenEmailIdentity ¶
func WebGitOperationGetCommitChosenEmailIdentity(ctx *context.Context, email string) (_ *files_service.IdentityOptions, valid bool)
func WikiRevision ¶
WikiRevision renders file revision list of wiki page
Types ¶
type CodeEditorConfig ¶
type CodeEditorConfig struct {
Filename string `json:"filename"` // the base name, not full path
Autofocus bool `json:"autofocus"`
PreviewableExtensions []string `json:"previewableExtensions,omitempty"`
LineWrapExtensions []string `json:"lineWrapExtensions,omitempty"`
LineWrap bool `json:"lineWrap"`
Previewable bool `json:"previewable,omitempty"`
// the following can be read from .editorconfig if exists, or use default value
IndentStyle string `json:"indentStyle"` // in most cases, keep it empty by default, detected by the source code
IndentSize int `json:"indentSize"`
TabWidth int `json:"tabWidth"`
TrimTrailingWhitespace *bool `json:"trimTrailingWhitespace,omitempty"`
}
CodeEditorConfig is also used by frontend, defined in "codeeditor" module
type IssuePageMetaData ¶
type IssuePageMetaData struct {
RepoLink string
Repository *repo_model.Repository
Issue *issues_model.Issue
IsPullRequest bool
CanModifyIssueOrPull bool
ReviewersData *issueSidebarReviewersData
LabelsData *issueSidebarLabelsData
MilestonesData *issueSidebarMilestoneData
ProjectsData *issueSidebarProjectsData
AssigneesData *issueSidebarAssigneesData
}
func (*IssuePageMetaData) SetSelectedProjectIDs ¶
func (d *IssuePageMetaData) SetSelectedProjectIDs(ids []int64)
type PageMeta ¶
type PageMeta struct {
Name string
SubURL string
GitEntryName string
UpdatedUnix timeutil.TimeStamp
}
PageMeta wiki page meta information
type RecentBranchesPromptDataStruct ¶
type RecentBranchesPromptDataStruct struct {
RecentlyPushedNewBranches []*git_model.RecentlyPushedNewBranch
}
type ReleaseInfo ¶
type ReleaseInfo struct {
Release *repo_model.Release
CommitStatus *git_model.CommitStatus
CommitStatuses []*git_model.CommitStatus
}
type WebDiffFileItem ¶
type WebDiffFileItem struct {
FullName string
DisplayName string
NameHash string
DiffStatus string
EntryMode string
IsViewed bool
Children []*WebDiffFileItem
FileIcon template.HTML
}
WebDiffFileItem is used by frontend, check the field names in frontend before changing
type WebDiffFileTree ¶
type WebDiffFileTree struct {
TreeRoot WebDiffFileItem
}
WebDiffFileTree is used by frontend, check the field names in frontend before changing
Source Files
¶
- activity.go
- attachment.go
- blame.go
- branch.go
- code_frequency.go
- commit.go
- common_recentbranches.go
- compare.go
- contributors.go
- download.go
- editor.go
- editor_apply_patch.go
- editor_cherry_pick.go
- editor_error.go
- editor_fork.go
- editor_preview.go
- editor_uploader.go
- editor_util.go
- fork.go
- githttp.go
- helper.go
- issue.go
- issue_comment.go
- issue_content_history.go
- issue_dependency.go
- issue_label.go
- issue_list.go
- issue_lock.go
- issue_new.go
- issue_page_meta.go
- issue_pin.go
- issue_poster.go
- issue_stopwatch.go
- issue_suggestions.go
- issue_timetrack.go
- issue_view.go
- issue_watch.go
- mention.go
- middlewares.go
- migrate.go
- milestone.go
- packages.go
- projects.go
- pull.go
- pull_merge_box.go
- pull_merge_form.go
- pull_review.go
- recent_commits.go
- release.go
- render.go
- repo.go
- search.go
- star.go
- topic.go
- transfer.go
- treelist.go
- view.go
- view_file.go
- view_home.go
- view_readme.go
- watch.go
- webgit.go
- wiki.go